import { Dispatch } from 'redux';
import { showToast, ToastType } from 'src/common/util/show-toast';
import { performApiCall } from 'src/services/api';
import { transformRequestUser, transformResponseUser } from '../transformations';

export enum UserActionTypes {
  FETCH_USERS = 'users/fetch_users',
  FETCH_USER = 'users/fetch_user',
  UPDATE_USER = 'users/update_user',
  CREATE_USER = 'users/create_user',
  DELETE_USER = 'users/delete_user',
  SET_USER_MODAL_LOADING = 'users/user_modal_loading',
}

export const fetchUsers = () => async (dispatch: Dispatch<any>) => {
  try {
    const { data } = await performApiCall({
      path: '/users',
      method: 'GET',
    });

    dispatch({
      type: UserActionTypes.FETCH_USERS,
      payload: data.map(transformResponseUser),
    });
  } catch (err) {
    console.error(err);
  }
};

export const setUserModalLoading = (isLoading: boolean) => (dispatch: Dispatch<any>) => {
  dispatch({
    type: UserActionTypes.SET_USER_MODAL_LOADING,
    payload: isLoading,
  });
};

export const fetchUserById = (id: string) => async (dispatch: Dispatch<any>) => {
  dispatch(setUserModalLoading(true));

  try {
    const { data } = await performApiCall({
      path: `/users/${id}`,
      method: 'GET',
    });

    dispatch({
      type: UserActionTypes.FETCH_USER,
      payload: transformResponseUser(data),
    });
  } catch (err) {
    console.error(err);
  }

  dispatch(setUserModalLoading(false));
};

export const updateUserById = (user: any) => async (dispatch: Dispatch<any>) => {
  dispatch(setUserModalLoading(true));

  try {
    const { data } = await performApiCall({
      path: `/users/${user.id}`,
      method: 'PUT',
      body: transformRequestUser(user),
    });

    dispatch({
      type: UserActionTypes.UPDATE_USER,
      payload: transformResponseUser(data),
    });

    showToast('User updated sucessfully.', ToastType.Success);

    dispatch(fetchUsers());
  } catch (err) {
    console.error(err);
  }

  dispatch(setUserModalLoading(false));
};

export const createUser = (user: any) => async (dispatch: Dispatch<any>) => {
  dispatch(setUserModalLoading(true));

  try {
    const { data } = await performApiCall({
      path: '/users',
      method: 'POST',
      body: transformRequestUser(user),
    });

    dispatch({
      type: UserActionTypes.CREATE_USER,
      payload: transformResponseUser(data),
    });

    showToast('User created sucessfully.', ToastType.Success);

    dispatch(fetchUsers());
  } catch (err: any) {
    dispatch(setUserModalLoading(false));
    showToast(`${err}`, ToastType.Error);
    throw err;
  }

  dispatch(setUserModalLoading(false));
};

export const deleteUser = (id: string) => async (dispatch: Dispatch<any>) => {
  dispatch(setUserModalLoading(true));

  try {
    await performApiCall({
      path: `/users/${id}`,
      method: 'DELETE',
    });

    dispatch({
      type: UserActionTypes.DELETE_USER,
      payload: {},
    });

    showToast('User deleted sucessfully.', ToastType.Success);

    dispatch(fetchUsers());
  } catch (err) {
    console.error(err);
  }

  dispatch(setUserModalLoading(false));
};
